==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QRenderSettings.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds settings related to rendering process and host the active FrameGraph</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html">Qt3DRender::QRenderSettings</a></p>
 */
public class QRenderSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderSettings.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::QRenderSettings::RenderPolicy</a></p>
     */
    public enum RenderPolicy implements io.qt.QtEnumerator {
        OnDemand(0),
        Always(1);

        private RenderPolicy(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static RenderPolicy resolve(int value) {
            switch (value) {
            case 0: return OnDemand;
            case 1: return Always;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::activeFrameGraphChanged(Qt3DRender::QFrameGraphNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="activeFrameGraph")
    public final Signal1<io.qt.qt3d.render.QFrameGraphNode> activeFrameGraphChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::renderPolicyChanged(Qt3DRender::QRenderSettings::RenderPolicy)</a></p>
     */
    @io.qt.QtPropertyNotify(name="renderPolicy")
    public final Signal1<io.qt.qt3d.render.QRenderSettings.RenderPolicy> renderPolicyChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRenderSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QRenderSettings(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::activeFrameGraph()const</a></p>
     */
    @io.qt.QtPropertyReader(name="activeFrameGraph")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QFrameGraphNode activeFrameGraph(){
        return activeFrameGraph_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QFrameGraphNode activeFrameGraph_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#pickingSettings-prop">Qt3DRender::QRenderSettings::pickingSettings()</a></p>
     */
    @io.qt.QtPropertyReader(name="pickingSettings")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QPickingSettings pickingSettings(){
        return pickingSettings_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QPickingSettings pickingSettings_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderCapabilities-prop">Qt3DRender::QRenderSettings::renderCapabilities()</a></p>
     */
    @io.qt.QtPropertyReader(name="renderCapabilities")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderCapabilities renderCapabilities(){
        return renderCapabilities_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QRenderCapabilities renderCapabilities_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::renderPolicy()const</a></p>
     */
    @io.qt.QtPropertyReader(name="renderPolicy")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderSettings.RenderPolicy renderPolicy(){
        return io.qt.qt3d.render.QRenderSettings.RenderPolicy.resolve(renderPolicy_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int renderPolicy_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::setActiveFrameGraph(Qt3DRender::QFrameGraphNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="activeFrameGraph")
    public final void setActiveFrameGraph(io.qt.qt3d.render.QFrameGraphNode activeFrameGraph){
        setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(activeFrameGraph));
    }
    
    private native void setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(long __this__nativeId, long activeFrameGraph);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::setRenderPolicy(Qt3DRender::QRenderSettings::RenderPolicy)</a></p>
     */
    @io.qt.QtPropertyWriter(name="renderPolicy")
    public final void setRenderPolicy(io.qt.qt3d.render.QRenderSettings.RenderPolicy renderPolicy){
        setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(QtJambi_LibraryUtilities.internal.nativeId(this), renderPolicy.value());
    }
    
    private native void setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(long __this__nativeId, int renderPolicy);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderSettings instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QRenderSettings.java <==
package io.qt.qt3d.render;


/**
 * <p>Holds settings related to rendering process and host the active FrameGraph</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html">Qt3DRender::QRenderSettings</a></p>
 */
public class QRenderSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderSettings.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::QRenderSettings::RenderPolicy</a></p>
     */
    public enum RenderPolicy implements io.qt.QtEnumerator {
        OnDemand(0),
        Always(1);

        private RenderPolicy(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static RenderPolicy resolve(int value) {
            switch (value) {
            case 0: return OnDemand;
            case 1: return Always;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::activeFrameGraphChanged(Qt3DRender::QFrameGraphNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="activeFrameGraph")
    public final Signal1<io.qt.qt3d.render.QFrameGraphNode> activeFrameGraphChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::renderPolicyChanged(Qt3DRender::QRenderSettings::RenderPolicy)</a></p>
     */
    @io.qt.QtPropertyNotify(name="renderPolicy")
    public final Signal1<io.qt.qt3d.render.QRenderSettings.RenderPolicy> renderPolicyChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRenderSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QRenderSettings(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::activeFrameGraph()const</a></p>
     */
    @io.qt.QtPropertyReader(name="activeFrameGraph")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QFrameGraphNode activeFrameGraph(){
        return activeFrameGraph_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QFrameGraphNode activeFrameGraph_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#pickingSettings-prop">Qt3DRender::QRenderSettings::pickingSettings()</a></p>
     */
    @io.qt.QtPropertyReader(name="pickingSettings")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QPickingSettings pickingSettings(){
        return pickingSettings_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QPickingSettings pickingSettings_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderCapabilities-prop">Qt3DRender::QRenderSettings::renderCapabilities()</a></p>
     */
    @io.qt.QtPropertyReader(name="renderCapabilities")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderCapabilities renderCapabilities(){
        return renderCapabilities_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QRenderCapabilities renderCapabilities_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::renderPolicy()const</a></p>
     */
    @io.qt.QtPropertyReader(name="renderPolicy")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderSettings.RenderPolicy renderPolicy(){
        return io.qt.qt3d.render.QRenderSettings.RenderPolicy.resolve(renderPolicy_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int renderPolicy_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::setActiveFrameGraph(Qt3DRender::QFrameGraphNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="activeFrameGraph")
    public final void setActiveFrameGraph(io.qt.qt3d.render.QFrameGraphNode activeFrameGraph){
        setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(activeFrameGraph));
    }
    
    private native void setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(long __this__nativeId, long activeFrameGraph);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::setRenderPolicy(Qt3DRender::QRenderSettings::RenderPolicy)</a></p>
     */
    @io.qt.QtPropertyWriter(name="renderPolicy")
    public final void setRenderPolicy(io.qt.qt3d.render.QRenderSettings.RenderPolicy renderPolicy){
        setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(QtJambi_LibraryUtilities.internal.nativeId(this), renderPolicy.value());
    }
    
    private native void setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(long __this__nativeId, int renderPolicy);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderSettings instance, QDeclarativeConstructor constructor);
    
}
